==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/MassIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MassIndexIndicatorDescription } from "./MassIndexIndicatorDescription";
/**
 * @hidden
 */
export let MassIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MassIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MassIndexIndicatorDescriptionMetadata.a == null) {
                MassIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MassIndexIndicatorDescriptionMetadata.c(MassIndexIndicatorDescriptionMetadata.a);
            }
            if (a.j(MassIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(MassIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MassIndexIndicatorDescriptionMetadata.b(a);
            a.aa("MassIndexIndicator", () => new MassIndexIndicatorDescription());
            a.z("MassIndexIndicator", MassIndexIndicatorDescriptionMetadata.a);
        }
    }
    MassIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(MassIndexIndicatorDescriptionMetadata, 'MassIndexIndicatorDescriptionMetadata');
    MassIndexIndicatorDescriptionMetadata.a = null;
    return MassIndexIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/MassIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MassIndexIndicatorDescription } from "./MassIndexIndicatorDescription";
/**
 * @hidden
 */
export let MassIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MassIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MassIndexIndicatorDescriptionMetadata.a == null) {
                MassIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MassIndexIndicatorDescriptionMetadata.c(MassIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(MassIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(MassIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MassIndexIndicatorDescriptionMetadata.b(a);
            a.ac("MassIndexIndicator", () => new MassIndexIndicatorDescription());
            a.ab("MassIndexIndicator", MassIndexIndicatorDescriptionMetadata.a);
        }
    }
    MassIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(MassIndexIndicatorDescriptionMetadata, 'MassIndexIndicatorDescriptionMetadata');
    MassIndexIndicatorDescriptionMetadata.a = null;
    return MassIndexIndicatorDescriptionMetadata;
})();
